#!/usr/bin/env bash

shopt -s dotglob
[[ "${DEBUG:-}" == 'true' ]] && set -x

SERVER_CFG='server.cfg'

set_default ()
{
    server_ip='0.0.0.0'
    server_port=''
    server_hostname=''
    server_maxplayers=''
    server_rcon_password=''
}

parse_options ()
{
    for i in "$@"
    do
        case $i in
            -h|--help)
                show_logo
                show_help
                exit 0
            ;;
            --ip=*|--host=*)
                server_ip="${i#*=}"
                shift
            ;;
            --port=*)
                server_port="${i#*=}"
                shift
            ;;
            --rcon-password=*)
                server_rcon_password="${i#*=}"
                shift
            ;;
            --hostname=*)
                server_hostname="${i#*=}"
                shift
            ;;
            --maxplayers=*)
                server_maxplayers="${i#*=}"
                shift
            ;;
        esac
    done
}

show_help ()
{
    echo
    echo 'Usage:	./samp_run.sh COMMAND [OPTIONS]'
    echo
    echo 'Options:'
    echo '      --ip=                   Server ip'
    echo '      --port=                 Server port'
    echo '      --rcon-password=        Server rcon password'
    echo '      --hostname=             Server hostname'
    echo '      --maxplayers=           Server maxplayers'
    echo
    echo 'Examples:'
    echo '      ./samp_run.sh --hostname="My Super Server" --ip=0.0.0.0 --port=7788'
}

show_logo ()
{
    echo
    echo '
                  ###           ####
               #######################
               #######################
              #######````````````#######
            ######   ############   ######
          #####  ####             ##  ########
      ########  ###               ####  ########
     ######## ###                 ###### ########
      ###### ####     ################### ######
       ####  ####     ################### #####
       #### #####     ###           #####  ####
       #### #####     ###           #####  ####
       ####  ####     #########     ##### #####
      ###### ####     #########     ##### ######
     ######## ###       ######      #### ########
      ########  ##                 ###  ########
       ########   ###            ###   #####
            #####    ############   ######
              #######````````````#######
                #######################
                #######################
                 #####          ####'
    echo
    echo '             GameAP SAMP Server Runner'
    echo
    echo '----------------------------------------------------'
    echo
}

set_properties ()
{
    if [[ ! -f "${SERVER_CFG}" ]]; then
        return
    fi

    if [[ -n "${server_maxplayers:-}" ]]; then
        sed -i "s/maxplayers .*$/maxplayers ${server_maxplayers}/" "${SERVER_CFG}"
    fi

    if [[ -n "${server_hostname:-}" ]]; then
        sed -i "s/hostname .*$/hostname ${server_hostname}/" "${SERVER_CFG}"
    fi

    if [[ -n "${server_ip:-}" ]]; then
        sed -i "s/bind .*$/bind ${server_ip}/" "${SERVER_CFG}"
    fi

    if [[ -n "${server_port:-}" ]]; then
        sed -i "s/port .*$/port ${server_port}/" "${SERVER_CFG}"
    fi

    if [[ -n "${server_rcon_password:-}" ]]; then
        sed -i "s/\#\?rcon_password .*$/rcon_password ${server_rcon_password}/" "${SERVER_CFG}"
        sed -i "s/\#\?rcon .*$/rcon 1/" "${SERVER_CFG}"
    else
        sed -i "s/\#\?rcon .*$/rcon 0/" "${SERVER_CFG}"
    fi
}

run ()
{
    if [[ ! -f ./samp03svr ]]; then
        echo
        echo "samp03svr file not found!"
        echo

        exit 1
    fi

    set_properties

    ./samp03svr
}

main ()
{
    show_logo
    run
}

set_default
parse_options "$@"
main